← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] ~jugmac00/launchpad:replace-charm-with-rocks into launchpad:master

 

Jürgen Gmach has proposed merging ~jugmac00/launchpad:replace-charm-with-rocks into launchpad:master.

Commit message:
Replace charm with rocks where this was not done yet

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~jugmac00/launchpad/+git/launchpad/+merge/473758
-- 
Your team Launchpad code reviewers is requested to review the proposed merge of ~jugmac00/launchpad:replace-charm-with-rocks into launchpad:master.
diff --git a/lib/lp/rocks/model/rockrecipe.py b/lib/lp/rocks/model/rockrecipe.py
index b4057e7..3ecb215 100644
--- a/lib/lp/rocks/model/rockrecipe.py
+++ b/lib/lp/rocks/model/rockrecipe.py
@@ -420,7 +420,7 @@ class RockRecipe(StormBase):
         )
 
     def getAllowedArchitectures(self):
-        """See `ICharmRecipe`."""
+        """See `IRockRecipe`."""
         store = Store.of(self)
         origin = [
             DistroArchSeries,
@@ -1048,11 +1048,11 @@ class RockRecipeSet:
         return rockcraft_data
 
     def findByOwner(self, owner):
-        """See `ICharmRecipeSet`."""
+        """See `IRockRecipeSet`."""
         return IStore(RockRecipe).find(RockRecipe, owner=owner)
 
     def detachFromGitRepository(self, repository):
-        """See `ICharmRecipeSet`."""
+        """See `IRockRecipeSet`."""
         recipes = self.findByGitRepository(repository)
         for recipe in recipes:
             get_property_cache(recipe)._git_ref = None

Follow ups
diff --git a/lib/lp/rocks/browser/hasrockrecipes.py b/lib/lp/rocks/browser/hasrockrecipes.py
index c88e33b..69fc10b 100644
--- a/lib/lp/rocks/browser/hasrockrecipes.py
+++ b/lib/lp/rocks/browser/hasrockrecipes.py
@@ -41,25 +41,25 @@ class HasRockRecipesViewMixin:
     @property
     def rock_recipes_link(self):
         """A link to rock recipes for this object."""
-        count = self.charm_recipes.count()
+        count = self.rock_recipes.count()
         if IGitRepository.providedBy(self.context):
             context_type = "repository"
         else:
             context_type = "branch"
         if count == 0:
             # Nothing to link to.
-            return "No charm recipes using this %s." % context_type
+            return "No rock recipes using this %s." % context_type
         elif count == 1:
             # Link to the single charm recipe.
             return structured(
-                '<a href="%s">1 charm recipe</a> using this %s.',
-                canonical_url(self.charm_recipes.one()),
+                '<a href="%s">1 rock recipe</a> using this %s.',
+                canonical_url(self.rock_recipes.one()),
                 context_type,
             ).escapedtext
         else:
             # Link to a charm recipe listing.
             return structured(
-                '<a href="+charm-recipes">%s charm recipes</a> using this %s.',
+                '<a href="+rock-recipes">%s rock recipes</a> using this %s.',
                 count,
                 context_type,
             ).escapedtext
@@ -41,25 +41,25 @@ class HasRockRecipesViewMixin:
         elif count == 1:
-            # Link to the single charm recipe.
+            # Link to the single rock recipe.
             return structured(
@@ -41,25 +41,25 @@ class HasRockRecipesViewMixin:
             ).escapedtext
         else:
-            # Link to a charm recipe listing.
+            # Link to a rock recipe listing.
             return structured(